@@ -46,4 +46,6 @@ TYPE_INFO_DICT = {
     "bbdc": "BBDC",
     "weread": "WeRead",
     "covid": "COVID-19",
+    "todoist": "Todoist",
+    "apple": "AppleHealth",
 }
