@@ -1,3 +1,4 @@
+from github_poster.loader.apple_health_loader import AppleHealthLoader
 from github_poster.loader.bbdc_loader import BBDCLoader
 from github_poster.loader.bilibili_loader import BilibiliLoader
 from github_poster.loader.cichang_loader import CiChangLoader
@@ -18,15 +19,18 @@ from github_poster.loader.multiple_loader import MultipleLoader
 from github_poster.loader.notion_loader import NotionLoader
 from github_poster.loader.nrc_loader import NRCLoader
 from github_poster.loader.ns_loader import NSLoader
+from github_poster.loader.openlanguage_loader import OpenLanguageLoader
 from github_poster.loader.shanbay_loader import ShanBayLoader
 from github_poster.loader.strava_loader import StravaLoader
 from github_poster.loader.summary_loader import SummaryLoader
+from github_poster.loader.todoist_loader import TodoistLoader
 from github_poster.loader.twitter_loader import TwitterLoader
 from github_poster.loader.wakatime_loader import WakaTimeLoader
 from github_poster.loader.weread_loader import WereadLoader
 from github_poster.loader.youtube_loader import YouTubeLoader
 
 LOADER_DICT = {
+    "apple_health": AppleHealthLoader,
     "bbdc": BBDCLoader,
     "duolingo": DuolingoLoader,
     "shanbay": ShanBayLoader,
@@ -54,9 +58,12 @@ LOADER_DICT = {
     "summary": SummaryLoader,
     "weread": WereadLoader,
     "covid": CovidLoader,
+    "todoist": TodoistLoader,
+    "openlanguage": OpenLanguageLoader,
 }
 
 __all__ = (
+    "AppleHealthLoader",
     "BilibiliLoader",
     "CiChangLoader",
     "Dota2Loader",
@@ -85,4 +92,6 @@ __all__ = (
     "BBDCLoader",
     "WereadLoader",
     "CovidLoader",
+    "TodoistLoader",
+    "OpenLanguageLoader",
 )
