@@ -14,7 +14,6 @@ class LoadError(Exception):
 
 
 class BaseLoader(ABC):
-
     parser_loader_list = []
     #: The track color of the poster
     track_color = None
@@ -211,7 +210,7 @@ class BaseLoader(ABC):
             "--cn",
             dest="cn",
             action="store_true",
-            help="if accout is CN",
+            help="if account is CN",
         )
         # special here
         group.add_argument(
