@@ -41,7 +41,7 @@ NS_CLAENDAR_URL = (
 # gpx need a gpx folder
 GPX_ACTIVITY_NAME_TUPLE = namedtuple("activity", "date distance")
 
-# GitHub for furture use
+# GitHub for future use
 GITHUB_BASE_URL = "https://github.com"
 
 # LeetCode
@@ -125,3 +125,97 @@ WEREAD_HISTORY_URL = (
 
 # COVID
 COVID_API = "https://pomber.github.io/covid19/timeseries.json"
+
+OPEN_LANGUAGE_LOGIN_URL = (
+    "https://api.openlanguage.com/passport/user/login/?"
+    "version_code=8.2.3&app_name=open_language"
+    "&vendor_id=5E43BCDC-D306-47C0-86D0-3248D4B77267"
+    "&device_id=884423380449783&channel=App%20Store"
+    "&mix_mode=1&multi_login=1&resolution=828%2A1792"
+    "&aid=1335&app_id=1335&install_id=180755913509454"
+    "&update_version_code=82300&ac=WIFI&os_version=16.0.2"
+    "&timezone=Asia%2FShanghai&ez_version=85&ssmix=a"
+    "&timezone_offset=28800000&device_platform=iphone"
+    "&iid=180755913509454&ab_client=a1%2Cf2%2Cf7%2Ce1"
+    "&device_type=iPhone11%2C8"
+)
+
+OPEN_LANGUAGE_X_LADON = "FMByTcspdXr0+Zu4p2x0j9698vNGIgJr2+7Y0hqdGnNW94US"
+
+OPEN_LANGUAGE_X_ARGUS = (
+    "uoviDe0vjDP7TP1eJ5GR1Iv3z0yZOjjZvO81C+Niy5FgO8ghZueIU"
+    "/yNG/ooGjfWjNZs2XBRSS/PIXsm8IZYKczptvpD2VoUajNVMGxWMv"
+    "PbygEzVtgvVCphnR+A7VNZQYNU217125E25PwuBFqx8j43qB/H29+u"
+    "P0h1FmNHePHDMB+FwHeeawWE9X2aT5zcZ2O/65deSknksNXFFCLGgp"
+    "H7u3HSfFj6hW2M+NRfda2JYOCU2N/eheYxXoZXmhnVfLE="
+)
+
+OPEN_LANGUAGE_RECORD_URL = (
+    "https://api.openlanguage.com/ez/studentapp/v15/clockInRecord"
+    "?start_date={start_date}&end_date={end_date}"
+)
+
+OPEN_LANGUAGE_ACCOUNT_PASSWORD_DICT = {
+    "0": "35",
+    "1": "34",
+    "2": "37",
+    "3": "36",
+    "4": "31",
+    "5": "30",
+    "6": "33",
+    "7": "32",
+    "8": "3d",
+    "9": "3c",
+    "a": "64",
+    "b": "67",
+    "c": "66",
+    "d": "61",
+    "e": "60",
+    "f": "63",
+    "g": "62",
+    "h": "6d",
+    "i": "6c",
+    "j": "6f",
+    "k": "6e",
+    "l": "69",
+    "m": "68",
+    "n": "6b",
+    "o": "6a",
+    "p": "75",
+    "q": "74",
+    "r": "77",
+    "s": "76",
+    "t": "71",
+    "u": "70",
+    "v": "73",
+    "w": "72",
+    "x": "7d",
+    "y": "7c",
+    "z": "7f",
+    "A": "44",
+    "B": "47",
+    "C": "46",
+    "D": "41",
+    "E": "40",
+    "F": "43",
+    "G": "42",
+    "H": "4d",
+    "I": "4c",
+    "J": "4f",
+    "K": "4e",
+    "L": "49",
+    "M": "48",
+    "N": "4b",
+    "O": "4a",
+    "P": "55",
+    "Q": "54",
+    "R": "57",
+    "S": "56",
+    "T": "51",
+    "U": "50",
+    "V": "53",
+    "W": "52",
+    "X": "5d",
+    "Y": "5c",
+    "Z": "5f",
+}
